---
title: "AI for healthcare"
author: "Jean Feydy"
institute: ""
topic: ""
theme: "metropolis"
colortheme:
fonttheme:
fontsize: 11pt
linkcolor: black
urlcolor: blue
linkstyle: bold
aspectratio: 169
titlegraphic: 
logo:
date:
section-titles: false
toc: false
---


## Recap of the previous lectures

To mitigate the **curse of dimensionality**, we use:

- **Expert** knowledge: high-quality features.

- Relevant **families** of functions: kernels, convolutional networks.

- Relevant **neighborhood** structures: graphs.

`\begin{center}`{=latex}

 \
Main challenge: $\BR{local}$ implementation $\Longrightarrow$ $\BR{global}$ understanding. \
\
Produce **guidelines** and **insights** for practitioners.
`\end{center}`{=latex}


## A continuous vocabulary for data sciences `\cite{geometric_data_analysis_feydy}`{=latex}

Lecture 5 -- From discrete graphs to **continuous spaces**:

- The Poincaré disk.
- Local metrics and geodesics.

$\BR{Lecture 6}$ -- From discrete samples to **continuous distributions**:

- **Why do we care** about probability distributions?
- Information **geometry**, kernels and optimal transport.
- **Lab session** on gradient descent.

$\Longrightarrow~~$ Chapter 3 of my PhD thesis, *Geometric data analaysis, beyond convolutions*.


# What is a probability distribution?

## Probability distribution $~~\alpha =$  weights $a_i$ at locations $x_i$ 


::: columns
:::: {.column width=32%}
`\begin{center}`{=latex}
![](images/density.png){height=4cm}

$\BR{Histogram:}$ \
**variable** weights $a_i$, \
**fixed** locations $x_i$.

`\end{center}`{=latex}
::::
:::: {.column width=32%}
`\begin{center}`{=latex}
![](images/sample.png){height=4cm}

$\BR{Sample:}$ \
**fixed** weights $1/\text{N}$, \
**variable** locations $x_i$.

`\end{center}`{=latex}
::::
:::: {.column width=32%}
`\begin{center}`{=latex}
![](images/cloud.png){height=4cm}

$\BR{Weighted point cloud:}$ \
**variable** weights $a_i$, \
**variable** locations $x_i$.

`\end{center}`{=latex}
::::
:::


`\begin{center}`{=latex}
**Discrete** sum $\alpha = \sum_{i=1}^\text{N} a_i \delta_{x_i}$
$~~\Longrightarrow~~$
**Continuous** density 
$\alpha = \int_x a(x) \, \mathrm{d} x~$. \
Today, we assume that $~~a \geqslant 0~~$ and sums up to 1.
`\end{center}`{=latex}


## Today's focus: quantifying distances between probability distributions

 \

::: columns
:::: {.column width=45%}
`\begin{center}`{=latex}
![](images/distances_1.pdf){height=4cm}

 \
We must **handle** both
$\source{\textbf{discrete}}$ and
$\target{\textbf{continuous}}$ distributions.

`\end{center}`{=latex}
::::
:::: {.column width=45%}
`\begin{center}`{=latex}
![](images/distances_2.pdf){height=4cm}

 \
We must **choose** if $\source{\alpha}$ is closer \
to $\target{\beta}~$ (same mean value) \
or to $\other{\gamma}~$ (same support).

`\end{center}`{=latex}
::::
:::





## Application 1: One-sample and Two-sample testing

::: columns
:::: {.column width=45%}
`\begin{center}`{=latex}
![](images/one_sample.pdf){height=4cm}

$\BR{One-sample test:}$ \
**discrete** observation $\textcolor{red!80!black}{\alpha}$, \
**continuous** model $\textcolor{blue!80!black}{\beta}$.

`\end{center}`{=latex}
::::
:::: {.column width=45%}
`\begin{center}`{=latex}
![](images/two_sample.pdf){height=4cm}


$\BR{Two-sample test:}$ \
**two discrete** observations $\textcolor{red!80!black}{\alpha}$ and $\textcolor{blue!80!black}{\beta}$.

`\end{center}`{=latex}
::::
:::

`\begin{center}`{=latex}

 \
Null hypothesis: $\textcolor{red!80!black}{\alpha}$ and $\textcolor{blue!80!black}{\beta}$ come from the **same distribution**.\
**Test:** reject if $\text{d}(\textcolor{red!80!black}{\alpha}, \textcolor{blue!80!black}{\beta})$ is too large.
`\end{center}`{=latex}


## Example: Splitting a population evenly for a clinical trial


::: columns
:::: {.column width=45%}
`\begin{center}\vspace*{.25cm}`{=latex}
![](images/clinical_trial_1.pdf){height=5cm}

**Problem 1:** ensure that the `\source{treatment}`{=latex} and `\target{control}`{=latex}
groups have similar characteristics.

`\end{center}`{=latex}
::::
:::: {.column width=45%}
`\begin{center}\vspace*{.25cm}`{=latex}
![](images/clinical_trial_2.pdf){height=5cm}


**Problem 2:** given a large population, pick a group of `\target{control}`{=latex} patients that have
similar characteristics to our `\source{treated}`{=latex} patients.

`\end{center}`{=latex}
::::
:::


## Application 2: Classification = regression in a space of distributions

::: columns
:::: {.column width=55%}
$\BR{Linear}$ regression:

- Encode class labels as **integer numbers** 
  $$l(x) \in \{1, 2, 3\}~.$$
- Predict a **score** $s(x)$ at every location $x$.
  `\vspace*{.2cm}`{=latex}
- Minimize the **least square error**:
  $$\frac{1}{\text{N}} \sum_{i=1}^\text{N} \big|l(x) - s(x) \big|^2~.$$

`\begin{center}\vspace*{.2cm}`{=latex}
Massive $\BR{bias}$ depending on \
the $\BR{ordering}$ of the labels.
`\end{center}`{=latex}

::::
:::: {.column width=40%}
`\begin{center}\vspace*{.6cm}`{=latex}
![](images/linear_regression.pdf){height=5cm}

2 input features, 3 classes.

`\end{center}`{=latex}
::::
:::



## Application 2: Classification = regression in a space of distributions

::: columns
:::: {.column width=55%}

`\vspace*{.2cm}`{=latex}
$\BR{Logistic}$ regression:

- Encode class labels as **probability distributions** 
  $~~\delta(x) \in \mathbb{P}(\{1, 2, 3\})~.$
  `\vspace*{.2cm}`{=latex}
- Predict a vector of **scores** $s_i(x)$ at every location $x$
  and turn it into a probability distribution using the **SoftMax**:
  $\alpha(x) = \big( e^{s_1(x)}, e^{s_2(x)}, e^{s_3(x)} \big)~/~ \sum e^{s_i(x)}$
  `\vspace*{.2cm}`{=latex}
- Minimize the **relative entropy**:
  $$\frac{1}{\text{N}} \sum_{i=1}^\text{N} \mathrm{KL}\big( \delta(x), \alpha(x)\big)~.$$

`\begin{center}`{=latex}
$\BR{Invariant}$ to the $\BR{ordering}$ of the labels.
`\end{center}`{=latex}

::::
:::: {.column width=40%}
`\begin{center}\vspace*{.7cm}`{=latex}
![](images/logistic_regression.pdf){height=5cm}

2 input features, 3 classes.

`\end{center}`{=latex}
::::
:::


## Application 3: Generative modelling

::: columns
:::: {.column width=48%}
`\begin{center}\vspace*{.25cm}`{=latex}
![](images/generative_gans.pdf){height=4.5cm}

Generative Adversarial Networks and Variational Auto-Encoders
**minimize a distance** between a `\source{synthetic sample}`{=latex}
and a `\target{reference data sample}`{=latex}.

`\end{center}`{=latex}
::::
:::: {.column width=48%}
`\begin{center}\vspace*{.25cm}`{=latex}
![](images/generative_diffusion.pdf){height=4.5cm}


Diffusion and score-based models estimate a gradient of the 
**distance to the support** of a `\target{reference data sample}`{=latex}.

`\end{center}`{=latex}
::::
:::




## Application 4: Shape registration `~\cite{kaltenmark2017general}`{=latex}

::: columns
:::: {.column width=32%}
`\begin{center}`{=latex}
![](images/curve_measure.png){height=4cm}

$\BR{Curve:}$ \
one weight per **segment**.

`\end{center}`{=latex}
::::
:::: {.column width=32%}
`\begin{center}`{=latex}
![](images/triangle.png){height=4cm}

$\BR{Surface:}$ \
one weight per **triangle**.

`\end{center}`{=latex}
::::
:::: {.column width=32%}
`\begin{center}`{=latex}
![](images/mini_bitmap.png){height=4cm}

$\BR{Segmentation mask:}$ \
one weight per **voxel**.

`\end{center}`{=latex}
::::
:::


`\begin{center}`{=latex}

 \
Encoding shapes as distributions guarantees an 
$\BR{invariance to resamplings}$. \
We may work with **basic** $(x,y,z)$ coordinates or with **better features**.
`\end{center}`{=latex}


## Application 4: Shape registration `~\cite{shen2021accurate}`{=latex}


`\begin{center}`{=latex}

![](images/robot_full.png){height=80%}

`\end{center}\vspace*{-.3cm}`{=latex}

`\begin{center}`{=latex}
Registration algorithms **minimize a distance** \
between a `\source{deformable model $\alpha$}`{=latex}
and the `\target{fixed target $\beta$}`{=latex}.
`\end{center}`{=latex}



## Application 5: Meta-analyses on histograms and distributions 


::: columns
:::: {.column width=35%}
`\begin{center}`{=latex}
![](images/curvatubes_diagrams.png){height=4cm}

3D shape **texture** \
$\simeq$ Distribution of **curvatures** \
$\kappa_1 \geqslant \kappa_2$ on the surface.

`\end{center}`{=latex}
::::
:::: {.column width=65%}
`\begin{center}`{=latex}
![](images/curvatubes_umap.png){height=4cm}

**UMAP representation** of a population of textures, \
from the matrix of Wasserstein **distances between curvature histograms**.

`\end{center}`{=latex}
::::
:::

`\begin{center}`{=latex}
Distances enable the processing of $\BR{populations of histograms}$. \
This is relevant to make **group-level** analyses.
`\end{center}`{=latex}



## A point about implementations

::: columns
:::: {.column width=32%}
`\begin{center}`{=latex}
![](images/density.png){height=4cm}

$\BR{Histogram:}$ \
**explicit** weights $a_i$, \
**implicit** locations $x_i$.

`\end{center}`{=latex}
::::
:::: {.column width=32%}
`\begin{center}`{=latex}
![](images/sample.png){height=4cm}

$\BR{Sample:}$ \
**implicit** weights $1/\text{N}$, \
**explicit** locations $x_i$.

`\end{center}`{=latex}
::::
:::: {.column width=32%}
`\begin{center}`{=latex}
![](images/cloud.png){height=4cm}

$\BR{Weighted point cloud:}$ \
**explicit** weights $a_i$, \
**explicit** locations $x_i$. $\vphantom{\big(\sum_i}$

`\end{center}`{=latex}
::::
:::


`\begin{center}`{=latex}
**Depending on the application**, we may choose \
a $\BR{different encoding}$ for our distributions.
`\end{center}`{=latex}



## A point about implementations

::: columns
:::: {.column width=32%}
`\begin{center}`{=latex}
![](images/measure_density.png){height=4cm}

$\BR{Histogram:}$ \
**explicit** weights $a_i$, \
**implicit** locations $x_i$.

`\end{center}`{=latex}
::::
:::: {.column width=32%}
`\begin{center}`{=latex}
![](images/measure_sample.png){height=4cm}

$\BR{Sample:}$ \
**implicit** weights $1/\text{N}$, \
**explicit** locations $x_i$.

`\end{center}`{=latex}
::::
:::: {.column width=32%}
`\begin{center}`{=latex}
![](images/measure_cloud.png){height=4cm}

$\BR{Weighted point cloud:}$ \
**explicit** weights $a_i$, \
**explicit** locations $x_i$. $\vphantom{\big(\sum_i}$

`\end{center}`{=latex}
::::
:::


`\begin{center}`{=latex}
Understanding that **different** $\BR{implementations}$ correspond to \
**the same** $\BR{operation}$ is key to insightful research in the field.
`\end{center}`{=latex}



## A point about implementations

::: columns
:::: {.column width=32%}
`\begin{center}`{=latex}
![](images/gaussian_density.png){height=4cm}

$\BR{Convolution}$ \
of the **density map** $a[\,i,\,j\,]$ \
with a filter $g[\,i,\,j\,]$.

`\end{center}`{=latex}
::::
:::: {.column width=32%}
`\begin{center}`{=latex}
![](images/gaussian_sample.png){height=4cm}

$\BR{Additive noise:}$ \
$x_i \mapsto x_i + w_i$ \
where $w_i \sim \mathcal{N}(0,\sigma^2)~.$

`\end{center}`{=latex}
::::
:::: {.column width=32%}
`\begin{center}`{=latex}
![](images/gaussian_contours.png){height=4cm}

$\BR{Soft distance:}$ \
log-likelihood $\ell(x) =$ \
$\log \big( \sum_i a_i e^{-\|x - x_i\|^2 / 2\sigma^2}  \big)~.$

`\end{center}`{=latex}
::::
:::


`\begin{center}`{=latex}
Understanding that **different** $\BR{implementations}$ correspond to \
**the same** $\BR{operation}$ is key to insightful research in the field.
`\end{center}`{=latex}





## A point about notations


`\vspace*{.25cm}`{=latex}
If $~\alpha = \sum_{i=1}^\text{N} a_i\delta_{x_i}~$ is a **probability distribution** \
and $~f:x\mapsto f(x)\in\mathbb{R}~$ is a **continuous function**,

```{=latex}
\vspace*{-.5cm}
\begin{align*}
\underbrace{\vphantom{\int_x}\sum_{i=1}^\text{N}a_i f(x_i)}_{\text{Programming}} 
~~=~~ 
\underbrace{\int_x f(x)\,\mathrm{d}\alpha(x)}_{\text{Integration}} 
~~=~~ 
\underbrace{\vphantom{\int_x} \langle\, \alpha\,,\, f\,\rangle}_{\text{Analysis}} 
~~=~~ 
\underbrace{\vphantom{\int_x}\mathbb{E}_{X\sim \alpha}\big[ f(X)\big]}_{\text{Probability}}~.
\end{align*}
```

 \
To study **spaces** of probability distributions, \
the $\langle\, \alpha \,, \, f \,\rangle$ notation is $\BR{superior}$ as it highlights \
the $\BR{linearity}$ with respect to **both** distributions and functions:

```{=latex}
\vspace*{-.5cm}
\begin{align*}
\langle\, \tfrac{1}{2}\alpha + \tfrac{1}{2}\beta \,, \, f \,\rangle
~~&=~~
\tfrac{1}{2}\langle\, \alpha \,, \, f \,\rangle + \tfrac{1}{2}\langle\,\beta \,, \, f \,\rangle~, \\
\langle\, \alpha \,, \, f + g\,\rangle
~~&=~~
\langle\, \alpha \,, \, f \,\rangle + \langle\,\alpha \,, \, g \,\rangle~.
\end{align*}
```


# Major distances between distributions


## Two main questions `~\cite{lion_photo}`{=latex}


`\begin{center}\vspace*{.25cm}`{=latex}
![](images/classification/classification.pdf){height=4.5cm}
`\end{center}`{=latex}

When **designing** a distance between histograms:

- Should we leverage the **distance** $\|x-y\|$ on the **"ground space" of labels**?
- How harshly should be we **penalize errors** on the estimation of the **support**?


## The total variation distance


::: columns
:::: {.column width=65%}

 \
The space of probability distributions on 
$$\{x_1, \dots, x_\text{K}\}$$
is a **simplex** of dimension $\text{K}-1$. \
\
The Total Variation is the L1--Manhattan distance:
$$
\mathrm{TV}(\source{\alpha},\target{\beta})
~=~
\sum_i |\source{a(x_i)} - \target{b(x_i)}|~.
$$

This distance:

- **Maxes out** at 2 with **disjoint** supports.
- Pays no attention to $\|x_i-x_j\|$.
- Pays no attention to **unlikely events**.

::::
:::: {.column width=32%}
`\begin{center}`{=latex}
![](images/total_variation.pdf){height=7cm}

`\end{center}`{=latex}
::::
:::


## Maximum likelihood and entropy

If `\target{$\beta = (b(1), \dots, b(\text{K}))~$ is a \textbf{model} distribution}`{=latex}
on $\{1, \dots, \text{K}\}$, \
the likelihood of observing a sample $x$ is
$~~\target{L_\beta}(x)~=~ \target{b(x)}~.$

$\BR{Assuming independence}$, the joint likelihood of a sample $(x_1, \dots, x_\text{N})$ is:
$$\target{L_\beta}(x_1, \dots, x_\text{N}) ~=~ \target{b(x_1) \cdots b(x_\text{N})}~.$$

Finding a sample $(x_1, \dots, x_\text{N})$ that **maximizes the likelihood** is equivalent
to minimizing:

```{=latex}
\vspace*{-.8cm}
\begin{align*}
\target{\ell_\beta}(x_1, \dots, x_\text{N}) 
~=~ 
- \frac{1}{\text{N}} \log \big[ L_\beta(x_1, \dots, x_\text{N}) \big]
~=~
\frac{1}{\text{N}} \sum_{i=1}^\text{N} \log\big[ 1 / \target{b(x_i)} \big]
\end{align*}
```

If the $x_i$ are drawn $\BR{independently}$ according to a `\source{data distribution $\alpha$}`{=latex}, this converges to:
```{=latex}
\vspace*{-.8cm}
\begin{align*}
\target{\ell_\beta}(\source{\alpha}) 
~=~
\lim_{\text{N}\rightarrow +\infty}
\sum_{k=1}^\text{K} \frac{\#\{\,i ~|~ x_i = k \,\} }{\text{N}} \log\big[ 1 / \target{b(k)}\big]
~=~
\sum_{k=1}^\text{K} \source{a(k)} \,\log\big[ 1 / \target{b(k)}\big]
\end{align*}
```


## Maximum likelihood and entropy

In practice, the `\source{data distribution $\alpha$}`{=latex} is fixed and we try to find \
a `\target{model distribution $\beta$ which is as likely as possible}`{=latex}.

This is equivalent to minimizing the $\BR{relative entropy}$ or **Kullback--Leibler** divergence:
$$
\mathrm{KL}(\source{\alpha}, \target{\beta})
~=~
\target{\ell_\beta}(\source{\alpha}) 
-
\source{\ell_\alpha}(\source{\alpha})~
~=~
\sum_{k=1}^\text{K} \source{a(k)} \,\log \big[ \source{a(k)} / \target{b(k)} \big].
$$

We have that $~\mathrm{KL}(\source{\alpha}, \source{\alpha}) = 0~$ and
$~\mathrm{KL}(\source{\alpha}, \target{\beta}) \geqslant 0$, since $\log$ is concave:
```{=latex}
\vspace*{-.7cm}
\begin{align*}
\log\big[ &\target{b(k)} / \source{a(k)}\big] ~~\leqslant~~ \target{b(k)} / \source{a(k)} - 1 \\
&\Longrightarrow 
\qquad\qquad  \log\big[ \source{a(k)} / \target{b(k)}\big] ~~\geqslant~~ 1 - \target{b(k)} / \source{a(k)} \\
&\Longrightarrow 
\sum_{k=1}^\text{K} \source{a(k)} \, \log\big[ \source{a(k)} / \target{b(k)}] ~~~\geqslant~~~  \sum_{k=1}^\text{K} \source{a(k)} \,\big[ 1 - \target{b(k)} / \source{a(k)}] ~=~0~.
\end{align*}
```


## First properties of the relative entropy

$\mathrm{KL}(\source{\alpha}, \target{\beta}) ~=~ \sum_{k=1}^\text{K} \source{a(k)} \,\log \big[ \source{a(k)} / \target{b(k)} \big] = \int_x \source{a(x)} \,\log \big[ \source{a(x)} / \target{b(x)} \big] \,\mathrm{d}x$ :

- Is $\BR{not symmetric}$ -- remember it as $\mathrm{KL}(\source{\text{data}} \,|\, \target{\text{model}})$.
- Is tied to an assumption of $\BR{independence}$.
- Historically: compression on communication networks $\Longrightarrow$ .zip format.

Crucially, the relative entropy:

- Pays no attention to $~\|x_i-x_j\|$.
- Pays **a lot** of attention to **unlikely events**: $\log(0^+) = -\infty$.


## Information geometry: the Fisher--Rao metric on statistical manifolds `~\cite{td_datascience}`{=latex}

::: columns
:::: {.column width=58%}

 \
The Gauss map defines a **parametric surface**:
$$\mathcal{N}:(m,\sigma)\in\mathbb{R}\times\mathbb{R}_+ \mapsto \mathcal{N}(m,\sigma) \in \mathbb{P}(\mathbb{R})~.$$

Direct computations show that:
```{=latex}
\vspace*{-.7cm}
\begin{align*}
&\mathrm{KL}\big( \source{\mathcal{N}(m+\mathrm{d}m,\sigma+\mathrm{d}\sigma)}, \target{\mathcal{N}(m,\sigma)}\big) \\
&~=~
\frac{\source{\tfrac{1}{2}\mathrm{d}m^2 + \mathrm{d}\sigma^2} }{\target{\sigma^2}}~+~ o(\source{\mathrm{d}m^2,\mathrm{d}\sigma^2})
\end{align*}
```

`\begin{center}`{=latex}
$\Longrightarrow~~$ **Poincaré** metric on the upper half-plane. \
With its $\BR{invariance to translation and scalings}$,
the relative entropy induces a **hyperbolic** geometry
on the surface of Gaussian distributions.
`\end{center}`{=latex}

::::
:::: {.column width=40%}
`\begin{center}`{=latex}
![](images/Gaussian_fisher_rao.png){height=7cm}

`\end{center}`{=latex}
::::
:::





## Kernel norms: recover compatibility with the addition

::: columns
:::: {.column width=65%}

 \
For
`\source{sources $\alpha = \sum_i a_i \delta_{x_i}$}`{=latex} and 
`\target{targets $\beta = \sum_j b_j \delta_{y_j}$}`{=latex}, \
choose a symmetric function $g$ that induces \
a convolution kernel $k = g\star g$ and use:
```{=latex}
\vspace*{-.5cm}
\begin{align*}
\mathrm{d}_k(\source{\alpha}, \target{\beta})
~&=~
\|\, g\star \source{\alpha} - g\star \target{\beta}\,\|_{L^2}^2 \\[.3cm]
~&=~ 
\langle \, 
\source{\alpha} - \target{\beta}\,,\,
k\star (\source{\alpha} - \target{\beta}) \,\rangle \\[.3cm]
~&=~
\source{\sum_i \sum_j a_i a_j \,k(x_i,x_j)} \\
&- 2 
\source{\sum_i} \target{\sum_j} \source{a_i} \target{b_j} \,k(\source{x_i},\target{y_j}) \\
&+ ~~
\target{\sum_i \sum_j b_i b_j \,k(y_i,y_j)}~.
\end{align*}
```


::::
:::: {.column width=35%}
`\begin{center}\vspace*{-.3cm}`{=latex}
![](images/data.png){height=3cm}

Distributions $\source{\alpha}$ and $\target{\beta}$.


![](images/combo_kernel.png){height=3cm}

Blurred signal $g \star (\source{\alpha} - \target{\beta})$.

`\end{center}`{=latex}
::::
:::

## Kernel norms: recover compatibility with the addition

**Kernel norms** (aka. Hilbert or Sobolev norms, Maximum Mean Discrepancies):

- Are **quadratic** with respect to the **weights** $\source{a_i}$ and $\target{b_j}$.
- Are compatible with the addition -- the geodesic from $\source{\alpha}$ to $\target{\beta}$ is:
  $$t\in[0,1] \mapsto (1-t)\,\source{\alpha} + t\,\target{\beta} ~.$$
- Have $\BR{wildly different behaviors}$ depending on $k(x,y)$: see the **lab session**.

Crucially, these formulas:

- Pay **a lot** of attention to $~\|x_i-y_j\|$.
- Pay little attention to **unlikely events**, \
  except if they are associated to **large values of $k(x,y)$**.


## Optimal transport (OT) generalizes sorting to spaces of dimension D $>$ 1



::: columns

:::: {.column width=70%}

`\vspace*{.3cm}`{=latex}

If $\a{\text{A} = (\text{x}_\text{1}, \dots, \text{x}_\text{N})}$  and  $\b{\text{B} = (\text{y}_\text{1}, \dots, \text{y}_\text{N})}$ \
are two clouds of N points in $\mathbb{R}^\text{D}$,
we define:


```{=latex}
\vspace*{-.3cm}
\begin{equation*}
\OT(\a{\text{A}},\b{\text{B}}) ~=~ \min_{\sigma \in \mathcal{S}_\text{N}}~ \frac{\text{1}}{\text{2N}} \sum_{\text{i\,=1}}^\text{N} \v{\|~\a{\text{x}_i} - \b{\text{y}_{\sigma(i)}}\|^2}
\end{equation*}
\vspace*{.2cm}
```

Generalizes **sorting** to metric spaces. \
**Linear problem** on the permutation matrix $\g{\text{P}}$:

```{=latex}
\begin{equation*}
\OT(\a{\alpha},\b{\beta}) ~=~ \min_{\g{\text{P}} \in \mathbb{R}^{\text{N}\times \text{N}} ~}
 \sum_{\text{i, j\,=1}}^{\text{N}} \g{\text{P}_{i,j}} \cdot \v{ \tfrac{\text{1}}{\text{2}} \|~ \a{\text{x}_i} - \b{\text{y}_j} \|^2 }~,
\end{equation*}
\vspace*{-.6cm}
\begin{align*}
&\text{s.t.} &
\g{ \text{P}_{i,j}} ~&\geqslant ~\text{0} &
\underbrace{\b{\textstyle\sum_j} \g{ \text{P}_{i,j}} ~=~ \a{a_i}}_{\text{Each source point\dots{}}}& &
\underbrace{\vphantom{\textstyle\sum_j}\a{\textstyle\sum_i} \g{ \text{P}_{i,j}} ~=~ \b{b_j}~.}_{\text{is transported onto the target.}}
\end{align*}

```

::::

:::: {.column width=25%}

```{=latex}
\begin{center}
	\begin{tikzpicture}[scale=.5,x=.7cm,y=-.7cm]
		%\node[anchor = east] at (0,4) {source};
		\draw[->,>=latex,thick,color=black]  (0,0)--(0,16.5);
		\node[circle,fill=red!80!black,inner sep=0pt,minimum size=7pt,label=left:{$\a{\text{x}_\text{1}}$}] (x1) at (0,1) {};
		\node[circle,fill=red!80!black,inner sep=0pt,minimum size=7pt,label=left:{$\a{\text{x}_\text{2}}$}] (x2) at (0,2) {};
		\node[circle,fill=red!80!black,inner sep=0pt,minimum size=7pt,label=left:{$\a{\text{x}_\text{3}}$}] (x3) at (0,3.5) {};
		\node[circle,fill=red!80!black,inner sep=0pt,minimum size=7pt,label=left:{$\a{\text{x}_\text{4}}$}] (x4) at (0,5) {};
		\node[circle,fill=red!80!black,inner sep=0pt,minimum size=7pt,label=left:{$\a{\text{x}_\text{5}}$}] (x5) at (0,7.5) {};


		%\node[anchor = east] at (0,0) {cible};
		\draw[->,>=latex,thick,color=black]  (4,0)--(4,16.5);
		\node[circle,fill=blue,inner sep=0pt,minimum size=7pt,label=right:{$\b{\text{y}_\text{3}}$}] (y1) at (4,5.5) {};
		\node[circle,fill=blue,inner sep=0pt,minimum size=7pt,label=right:{$\b{\text{y}_\text{5}}$}] (y2) at (4,7) {};
		\node[circle,fill=blue,inner sep=0pt,minimum size=7pt,label=right:{$\b{\text{y}_\text{2}}$}] (y3) at (4,8.5) {};
		\node[circle,fill=blue,inner sep=0pt,minimum size=7pt,label=right:{$\b{\text{y}_\text{4}}$}] (y4) at (4,12.5) {};
		\node[circle,fill=blue,inner sep=0pt,minimum size=7pt,label=right:{$\b{\text{y}_\text{1}}$}] (y5) at (4,15) {};

		\node[anchor = north, align=center, color=otplan!70!black] at (2,17) {{assignment}\\ ${\sigma:\zp[i]{1,5}\rightarrow \zp[i]{1,5}}$};

		\draw[color=otplan,very thick] (x1) -- (y1) (x2) -- (y2) (x3) -- (y3) (x4) -- (y4) (x5) -- (y5);

		%\onslide<2,3,4,6->{\draw[color=green!80!black,thick] (x3) -- (y3) (x4) -- (y4);}
		%\onslide<5>{\draw[color=green!80!black] (x4) -- (y3);
		%\draw[color=green!80!black, very thick] (x3) -- (y4);}

	\end{tikzpicture}
	\end{center}
```

::::

:::



## Practical use

Alternatively, we understand OT as:

- Nearest neighbor **projection** + **incompressibility** constraint. \

- Fundamental example of **linear optimization** over the transport plan $\g{ \text{P}_{i,j}}$.

\
This theory induces two main quantities:

- The transport plan $\g{ \text{P}_{i,j}}$ $\simeq$ the optimal mapping $~\a{x_i} \mapsto \b{y_{\sigma(i)}}$. \

- The "Wasserstein" distance $\sqrt{\OT(\a{\text{A}},\b{\text{B}})}$.


```{=latex}
\end{frame}

\begin{frame}{The optimal transport plan}
	\vspace*{1cm}

	\centerline{
	\begin{tabular}{ccc}
	\includegraphics<1>[height=6cm]{images/registration_2D/densities/000.png}%
	\includegraphics<2>[height=6cm]{images/registration_2D/crescents/000.png}%
	\includegraphics<3>[height=6cm]{images/registration_2D/worms/000.png}%
	\includegraphics<4>[height=6cm]{images/registration_2D/moons/000.png}%
	&\qquad&
	\includegraphics<1>[height=6cm]{images/registration_2D/densities/010.png}%
	\includegraphics<2>[height=6cm]{images/registration_2D/crescents/010.png}%
	\includegraphics<3>[height=6cm]{images/registration_2D/worms/010.png}%
	\includegraphics<4>[height=6cm]{images/registration_2D/moons/010.png}%
	\\
	Before
	&&
	After
	\end{tabular}
	}

```


## The Wasserstein metric on statistical manifolds `~\cite{peyre}`{=latex}

::: columns
:::: {.column width=58%}

 \
The Gauss map defines a **parametric surface**:
$$\mathcal{N}:(m,\sigma)\in\mathbb{R}\times\mathbb{R}_+ \mapsto \mathcal{N}(m,\sigma) \in \mathbb{P}(\mathbb{R})~.$$

Direct computations show that:
```{=latex}
\vspace*{-.7cm}
\begin{align*}
2\,& \mathrm{OT}\big( \source{\mathcal{N}(m_1,\sigma_1)}, \target{\mathcal{N}(m_2,\sigma_2)}\big) \\
~=~&
(\source{m_1} - \target{m_2})^2 ~+~
(\source{\sigma_1} - \target{\sigma_2})^2~.
\end{align*}
```

`\begin{center}`{=latex}
$\Longrightarrow~~$ **Euclidean** metric on the upper half-plane. \
Optimal transport $\BR{lifts the geometry}$ $\BR{of the sample space}$
to the surface \
of Gaussian distributions.
`\end{center}`{=latex}

::::
:::: {.column width=40%}
`\begin{center}`{=latex}
![](images/Gaussian_wasserstein.png){height=7cm}

`\end{center}`{=latex}
::::
:::

## Two canonical distances between Gaussian distributions  `\cite{peyre}`{=latex}


::: columns
:::: {.column width=45%}
`\begin{center}`{=latex}
![](images/Gaussian_wasserstein.png){height=5.5cm}

 \
Gaussians + **Wasserstein** metric \
$=~~$ $\BR{Euclidean}$.

`\end{center}`{=latex}
::::
:::: {.column width=45%}
`\begin{center}`{=latex}
![](images/Gaussian_fisher_rao.png){height=5.5cm}

 \
Gaussians + relative **entropy** \
$=~~$ $\BR{Poincaré}$.

`\end{center}`{=latex}
::::
:::


## Geometric solutions to least square problems `\cite{agueh_2011}`{=latex}

```{=latex}
\vspace*{-.5cm}
\begin{align*}
	\text{Barycenter}~~\a{\al^*}
	~=~\arg \min_{\a{\al}} 
	\sum_{i=1}^4 \,\lambda_i\,\text{Loss}(\,\a{\al}\,,\, \b{\be_i}\,)~.
\end{align*}
```

::: columns

:::: {.column width=45%}

`\begin{center}`{=latex}

![](images/wasserstein/linear_barycenters.png){height=60%}

**Euclidean** barycenters. \
$\text{Loss}(\a{\al},\b{\be}) = \|\a{\al}-\b{\be}\|^2_{L^2}$

`\end{center}`{=latex}

::::

:::: {.column width=45%}

`\begin{center}`{=latex}

![](images/wasserstein/wasserstein_barycenters.png){height=60%}

**Wasserstein** barycenters. \
$\text{Loss}(\a{\al},\b{\be}) = \OT(\a{\al},\b{\be})$

`\end{center}`{=latex}

::::

:::


## How should we solve the OT problem?

Key dates for discrete optimal transport with N points:

- `\cite{kantorovich1942translocation}`{=latex}: `\defi{Dual}`{=latex} problem of Kantorovitch.
- `\cite{kuhn1955hungarian}`{=latex}: `\defi{Hungarian}`{=latex} methods in $O(\text{N}^3)$.
- `\cite{bertsekas79auction}`{=latex}: **Auction** algorithm in $O(\text{N}^2)$.
- `\cite{kosowsky1994invisible}`{=latex}: **SoftAssign** = Sinkhorn + simulated annealing, in $O(\text{N}^2)$.
- `\cite{gold1998new,TPSRPM}`{=latex}: **Robust Point Matching** = Sinkhorn as a loss.
- `\cite{CuturiSinkhorn}`{=latex}: Start of the `\contexte{GPU era.}`{=latex}
- `\cite{merigot2011multiscale,levy2015numerical,schmitzer2019stabilized}`{=latex}: **multi-scale** solvers in $O(\text{N}\log \text{N})$. \
  $~$
- `\solution{Solution,}`{=latex}today: **Multiscale Sinkhorn algorithm, on the GPU**.


`\begin{center}`{=latex}
$\Longrightarrow$ Generalized `\solution{QuickSort}`{=latex}algorithm, \
$\simeq O(\text{N}\log \text{N})$ if $\text{D}$ is small, fast $O(\text{N}^2)$ otherwise.
`\end{center}`{=latex}


## Scaling up optimal transport to anatomical data

```{=latex}

\begin{center} 
	Progresses of the last decade add up to a 
	$\times \textbf{100}$ - $\times \textbf{1000}$ acceleration:
	
	Sinkhorn GPU
	$\xrightarrow{\times \text{10}}$
	+ KeOps
	$\xrightarrow{\times \text{10}}$
	+ Annealing
	$\xrightarrow{\times \text{10}}$
	+ Multi-scale
	
	
	With a precision of 1\%, on a gaming GPU:\\~
	\end{center}

	\vspace*{-.25cm}
	\begin{tabular}{cccc}
	\begin{minipage}{.2\linewidth}
	\begin{center}
	~\\
	\texttt{pip install geomloss}\\
	+\\
	modern GPU\\ (1 000 €)
	\end{center}
	\end{minipage}
	&
	\begin{minipage}{.1\linewidth}
	~\\
	$\Longrightarrow$
	\end{minipage}
	&
	\begin{minipage}{.3\linewidth}
	\includegraphics[height=3.5cm]{images/dragon_ball/lowres.png}
	\end{minipage}
	&
	\begin{minipage}{.3\linewidth}
	\includegraphics[height=3.5cm]{images/dragon_ball/highres.png}
	\end{minipage}
	\\
	&&
	10k points in 30-50ms
	&
	\textbf{100k points in 100-200ms}
	\end{tabular}
```


## Recap on classical distances between probability distributions

The **Total Variation**:

- **Invariant** to the ground metric $\|\,\source{x_i}-\target{y_j}\,\|$, only cares about **large** weights $\source{a_i}$ and $\target{b_j}$.

The **relative entropy** $\mathrm{KL}$:

- $\BR{Invariant}$ to the ground metric $\|\,\source{x_i}-\target{y_j}\,\|$, cares about the **ratio** $~\source{a_i}\, /\, \target{b_j}$.


**Kernel** norms:

- More or less **faitfhul** to the ground metric **depending** on $k$, easy to scale on GPUs.


**Optimal transport** distances:

- $\BR{Extremely faithful}$ to the ground metric $\|\,\source{x_i}-\target{y_j}\,\|$.
- **Scalability** is recent -- still open on general graphs and manifolds.

## Open problem 1: Topology-aware distances


::: columns
:::: {.column width=65%}

 \
"OT that preserves the neighborhood structure"? \
\
The problem has been studied for decades:

- **Optimization:** Quadratic assignment...
- **Optimal Transport:** Gromov--Wasserstein...
- **Fluid mechanics:** Camassa--Holm equation...
- **Shape analysis:** LDDMM, SVF...
- **Statistics:** Stein Variational Gradient Descent...
- **Deep learning:** Neural ODEs...

`\begin{center}`{=latex}

 \
Mature tools exist but remain \
$\geqslant \text{100}$ $\BR{slower}$ than Optimal Transport.
`\end{center}`{=latex}


::::
:::: {.column width=35%}
`\begin{center}\vspace*{-.3cm}`{=latex}
![](images/shoot_0.png){height=3cm}

Initial configuration.


![](images/shoot_10.png){height=3cm}

**Diffeomorphic** displacement.

`\end{center}`{=latex}
::::
:::



## Open problem 2: The curse of dimensionality

::: columns
:::: {.column width=48%}
`\begin{center}\vspace*{.25cm}`{=latex}

 \
\
In **high dimension**, the matrix of Euclidean distances stops \
being informative. \
\
Standard kernels and OT metrics are overwhelmed by **statistical noise**. \
\
How can we compute **meaningful distances and gradients**?

`\end{center}`{=latex}
::::
:::: {.column width=48%}
`\begin{center}\vspace*{.25cm}`{=latex}
![](images/generative_gans.pdf){height=4.5cm}

GANs and VAEs **minimize a distance** between a `\source{synthetic sample}`{=latex}
and a `\target{reference data sample}`{=latex}.

`\end{center}`{=latex}
::::
:::

```{=latex}
\end{frame}

\begin{frame}{Dual norms: a fundamental insight from functional analysis}

	\vspace{-.5cm}
\begin{align*}
\text{Loss}(\a{\alpha},\b{\beta})~=~
&\max_{f\,\in\, B}~ \langle\,\a{\alpha}-\b{\beta}\,,\,f\,\rangle, \\
\text{look for}~~
\a{\theta^*}
~=~\arg\min_{\a{\theta}\vphantom{\in B}} &\max_{f\,\in\, B} ~
\langle\,\a{\alpha(\theta)}-\b{\beta}\,,\,f\,\rangle
\end{align*}

\begin{itemize}
\item $B = \{ \, \|\,f\,\|_\infty \leqslant 1\,\}$ ~$\Longrightarrow$~ 
 $\text{Loss} = \text{TV norm}$:
	\begin{itemize}
		\item Zero geometry, always saturates on disjoint samples.
		\item \textbf{Too many} test functions.
	\end{itemize}
\item $B = \{ \, \|\,f\,\|_{L^2}^2 + \|\,\nabla f\,\|_{L^2}^2 + \cdots \leqslant 1\,\}$~$\Longrightarrow$~ 
	$\text{Loss} = \text{kernel norm}$:
	\begin{itemize}
    \item Screening artifacts -- see lab session.
		\item In high dimension, samples are at equal distance from each other. \\
    \textbf{``Smooth''} functions are either ``constant'' or \textbf{``bounded''}: fall back on TV behavior.
	\end{itemize}
\end{itemize}
\end{frame}


\begin{frame}{Dual norms: link with the GANs literature}

	\vspace{-.5cm}
\begin{align*}
\text{Loss}(\a{\alpha},\b{\beta})~=~
&\max_{f\,\in\, B}~ \langle\,\a{\alpha}-\b{\beta}\,,\,f\,\rangle, \\
\text{look for}~~
\a{\theta^*}
~=~\arg\min_{\a{\theta}\vphantom{\in B}} &\max_{f\,\in\, B} ~
\langle\,\a{\alpha(\theta)}-\b{\beta}\,,\,f\,\rangle
\end{align*}

\begin{itemize}
\item $B = \{ \, \text{$f$ is 1-Lipschitz}\,\}$~$\Longrightarrow$~ 
	$\text{Loss} = \text{Wasserstein-1}$:  
	\begin{itemize}
		\item Modern solvers are nearly as efficient as a 
			  \textbf{closed formula}.
		\item \textbf{Useless} in $(\R^{512\times 512}, \|\cdot\|_2)$:
		      the ground cost makes no sense.
	\end{itemize}
  
	\item $B \simeq \{ \, \text{$f$ is 1-Lipschitz}\,\} \bigcap\,
	\{ \, \text{$f$ is a \textbf{CNN}}\,\}$ 
	 ~$\Longrightarrow$~ 
		$\text{Loss} = \text{Wasserstein--GAN}$~:
		\begin{itemize}
			\item Use \textbf{perceptual} test functions.
      \item No simple formula: use \textbf{gradient ascent}. \\
      Leads to a cumbersome min-max optimization.
			
		\end{itemize}
\end{itemize}
\end{frame}

```

## Open problem 2: Understand the impact of domain-specific test functions $f$

::: columns
:::: {.column width=48%}
`\begin{center}\vspace*{.25cm}`{=latex}

\
Similar story for **diffusion models**: we use **CNNs** (U-Nets...) to predict
the gradient of the distance to the set of **natural images**. \
\
The $\BR{interplay}$ between **mathematical insights** derived from toy models 
and **numerical experiments** on modern hardware is at the $\BR{heart of ML research}$. \
\
Let's play with gradient descent to $\BR{build an intuition}$ about \
classical formulas!

`\end{center}`{=latex}
::::
:::: {.column width=48%}
`\begin{center}\vspace*{.5cm}`{=latex}
![](images/generative_diffusion.pdf){height=4.5cm}

Diffusion and score-based models estimate a gradient of the 
**distance to the support** of a `\target{reference data sample}`{=latex}.

`\end{center}`{=latex}
::::
:::



# References

